Particle Swarm Optimizer (PSO)
==============================

.. autoclass:: pypop7.optimizers.pso.pso.PSO



.. toctree::
   :maxdepth: 2
   :caption: PSOs:

   ccpso2
   ipso
   clpso
   spsol
   spso
